==> tencentcloud-sdk-java-3.1.920-sources.jar: com/tencentcloudapi/iai/v20200303/models/FaceQualityCompleteness.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.iai.v20200303.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class FaceQualityCompleteness extends AbstractModel {

    /**
    * 眉毛的遮挡分数[0,100]，分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Eyebrow")
    @Expose
    private Long Eyebrow;

    /**
    * 眼睛的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Eye")
    @Expose
    private Long Eye;

    /**
    * 鼻子的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Nose")
    @Expose
    private Long Nose;

    /**
    * 脸颊的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Cheek")
    @Expose
    private Long Cheek;

    /**
    * 嘴巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Mouth")
    @Expose
    private Long Mouth;

    /**
    * 下巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Chin")
    @Expose
    private Long Chin;

    /**
     * Get 眉毛的遮挡分数[0,100]，分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Eyebrow 眉毛的遮挡分数[0,100]，分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getEyebrow() {
        return this.Eyebrow;
    }

    /**
     * Set 眉毛的遮挡分数[0,100]，分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Eyebrow 眉毛的遮挡分数[0,100]，分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setEyebrow(Long Eyebrow) {
        this.Eyebrow = Eyebrow;
    }

    /**
     * Get 眼睛的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Eye 眼睛的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getEye() {
        return this.Eye;
    }

    /**
     * Set 眼睛的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Eye 眼睛的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setEye(Long Eye) {
        this.Eye = Eye;
    }

    /**
     * Get 鼻子的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Nose 鼻子的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getNose() {
        return this.Nose;
    }

    /**
     * Set 鼻子的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Nose 鼻子的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setNose(Long Nose) {
        this.Nose = Nose;
    }

    /**
     * Get 脸颊的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Cheek 脸颊的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getCheek() {
        return this.Cheek;
    }

    /**
     * Set 脸颊的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Cheek 脸颊的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCheek(Long Cheek) {
        this.Cheek = Cheek;
    }

    /**
     * Get 嘴巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Mouth 嘴巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getMouth() {
        return this.Mouth;
    }

    /**
     * Set 嘴巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Mouth 嘴巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setMouth(Long Mouth) {
        this.Mouth = Mouth;
    }

    /**
     * Get 下巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Chin 下巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getChin() {
        return this.Chin;
    }

    /**
     * Set 下巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Chin 下巴的遮挡分数[0,100],分数越高遮挡越少。 
参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setChin(Long Chin) {
        this.Chin = Chin;
    }

    public FaceQualityCompleteness() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public FaceQualityCompleteness(FaceQualityCompleteness source) {
        if (source.Eyebrow != null) {
            this.Eyebrow = new Long(source.Eyebrow);
        }
        if (source.Eye != null) {
            this.Eye = new Long(source.Eye);
        }
        if (source.Nose != null) {
            this.Nose = new Long(source.Nose);
        }
        if (source.Cheek != null) {
            this.Cheek = new Long(source.Cheek);
        }
        if (source.Mouth != null) {
            this.Mouth = new Long(source.Mouth);
        }
        if (source.Chin != null) {
            this.Chin = new Long(source.Chin);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Eyebrow", this.Eyebrow);
        this.setParamSimple(map, prefix + "Eye", this.Eye);
        this.setParamSimple(map, prefix + "Nose", this.Nose);
        this.setParamSimple(map, prefix + "Cheek", this.Cheek);
        this.setParamSimple(map, prefix + "Mouth", this.Mouth);
        this.setParamSimple(map, prefix + "Chin", this.Chin);

    }
}

==> tencentcloud-sdk-java-3.1.1157-sources.jar: com/tencentcloudapi/iai/v20200303/models/FaceQualityCompleteness.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.iai.v20200303.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class FaceQualityCompleteness extends AbstractModel {

    /**
    * 眉毛的遮挡分数。
- 取值范围：[0,100]，分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Eyebrow")
    @Expose
    private Long Eyebrow;

    /**
    * 眼睛的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Eye")
    @Expose
    private Long Eye;

    /**
    * 鼻子的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Nose")
    @Expose
    private Long Nose;

    /**
    * 脸颊的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Cheek")
    @Expose
    private Long Cheek;

    /**
    * 嘴巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Mouth")
    @Expose
    private Long Mouth;

    /**
    * 下巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Chin")
    @Expose
    private Long Chin;

    /**
     * Get 眉毛的遮挡分数。
- 取值范围：[0,100]，分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Eyebrow 眉毛的遮挡分数。
- 取值范围：[0,100]，分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getEyebrow() {
        return this.Eyebrow;
    }

    /**
     * Set 眉毛的遮挡分数。
- 取值范围：[0,100]，分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Eyebrow 眉毛的遮挡分数。
- 取值范围：[0,100]，分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setEyebrow(Long Eyebrow) {
        this.Eyebrow = Eyebrow;
    }

    /**
     * Get 眼睛的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Eye 眼睛的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getEye() {
        return this.Eye;
    }

    /**
     * Set 眼睛的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Eye 眼睛的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,80]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setEye(Long Eye) {
        this.Eye = Eye;
    }

    /**
     * Get 鼻子的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Nose 鼻子的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getNose() {
        return this.Nose;
    }

    /**
     * Set 鼻子的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Nose 鼻子的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,60]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setNose(Long Nose) {
        this.Nose = Nose;
    }

    /**
     * Get 脸颊的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Cheek 脸颊的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getCheek() {
        return this.Cheek;
    }

    /**
     * Set 脸颊的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Cheek 脸颊的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCheek(Long Cheek) {
        this.Cheek = Cheek;
    }

    /**
     * Get 嘴巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Mouth 嘴巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getMouth() {
        return this.Mouth;
    }

    /**
     * Set 嘴巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Mouth 嘴巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,50]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setMouth(Long Mouth) {
        this.Mouth = Mouth;
    }

    /**
     * Get 下巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Chin 下巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getChin() {
        return this.Chin;
    }

    /**
     * Set 下巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     * @param Chin 下巴的遮挡分数。
- 取值范围：[0,100],分数越高遮挡越少。 
- 参考范围：[0,70]表示发生遮挡。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setChin(Long Chin) {
        this.Chin = Chin;
    }

    public FaceQualityCompleteness() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public FaceQualityCompleteness(FaceQualityCompleteness source) {
        if (source.Eyebrow != null) {
            this.Eyebrow = new Long(source.Eyebrow);
        }
        if (source.Eye != null) {
            this.Eye = new Long(source.Eye);
        }
        if (source.Nose != null) {
            this.Nose = new Long(source.Nose);
        }
        if (source.Cheek != null) {
            this.Cheek = new Long(source.Cheek);
        }
        if (source.Mouth != null) {
            this.Mouth = new Long(source.Mouth);
        }
        if (source.Chin != null) {
            this.Chin = new Long(source.Chin);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Eyebrow", this.Eyebrow);
        this.setParamSimple(map, prefix + "Eye", this.Eye);
        this.setParamSimple(map, prefix + "Nose", this.Nose);
        this.setParamSimple(map, prefix + "Cheek", this.Cheek);
        this.setParamSimple(map, prefix + "Mouth", this.Mouth);
        this.setParamSimple(map, prefix + "Chin", this.Chin);

    }
}
